@@ -16,6 +16,7 @@ OC.L10N.register(
     "Filename" : "اسم الملف",
     "Cancel" : "إلغاء",
     "Automatic" : "تلقائي",
+    "Actions" : "الإجراءات",
     "Show week numbers" : "إظهار رقم الأسابيع",
     "Settings & import" : "الإعدادات و الإستيراد",
     "Email" : "البريد الإلكتروني",
@@ -33,13 +34,13 @@ OC.L10N.register(
     "Details" : "التفاصيل",
     "Attendees" : "المشاركون",
     "Reminders" : "تذكيرات",
-    "Activity" : "نشاط",
-    "Projects" : "المشاريع",
     "Close" : "إغلاق",
     "Anniversary" : "ذكرى سنوية",
     "Week {number} of {year}" : "الأسبوع {number} من {year}",
     "Daily" : "يومي",
     "Weekly" : "أسبوعي",
+    "next year" : "العام القادم",
+    "today" : "اليوم",
     "When shared show full event" : "عرض الحدث كاملاً عند مشاركته",
     "When shared show only busy" : "عرض مشغول عند مشاركة الحدث",
     "When shared hide this event" : "إخفاء الحدث عند مشاركته",
@@ -48,8 +49,8 @@ OC.L10N.register(
     "Status" : "الحالة",
     "Confirmed" : "مؤكَّد",
     "Tentative" : "مبدئي",
-    "Cancelled" : "ملغى",
     "Categories" : "الفئات",
+    "Movie" : "فلم",
     "Cinema" : "سينما",
     "Mail" : "البريد",
     "Play" : "تشغيل",
