@@ -26,6 +26,7 @@ OC.L10N.register(
     "Filename" : "Dosiernomo",
     "Cancel" : "Nuligi",
     "Automatic" : "Aŭtomata",
+    "Actions" : "Agoj",
     "Show week numbers" : "Montri numerojn de semajno",
     "Settings & import" : "Agordoj kaj enporto",
     "Email" : "Retpoŝto",
@@ -40,18 +41,21 @@ OC.L10N.register(
     "More" : "Pli",
     "Save" : "Konservi",
     "Update" : "Ĝisdatigi",
-    "Select Date" : "Elekti daton",
     "Personal" : "Persona",
+    "[Today]" : "[Hodiaŭ]",
+    "[Tomorrow]" : "[Morgaŭ]",
+    "[Yesterday]" : "[Hieraŭ]",
     "Details" : "Detaloj",
     "Attendees" : "Ĉeestontoj",
     "Reminders" : "Memorigoj",
-    "Activity" : "Aktivaĵoj",
     "Close" : "Fermi",
     "Anniversary" : "Datreveno",
     "Week {number} of {year}" : "Semajno {number} en {year}",
     "Daily" : "Ĉiutage",
     "Weekly" : "Ĉiusemajne",
     "Untitled event" : "Sentitola okazaĵo",
+    "next year" : "venontjare",
+    "today" : "hodiaŭ",
     "When shared show full event" : "Kiam kunhavigita, montri plenajn detalojn",
     "When shared show only busy" : "Kiam kunhavigita, montri nur kiel okupita",
     "When shared hide this event" : "Kiam kunhavigita, kaŝi tiun okazaĵon",
@@ -60,7 +64,7 @@ OC.L10N.register(
     "Status" : "Stato",
     "Confirmed" : "Konfirmita",
     "Tentative" : "Nekonfirmita",
-    "Cancelled" : "Nuligita",
+    "Canceled" : "Nuligita",
     "Categories" : "Kategorioj",
     "Add this as a new category" : "Aldoni tion kiel novan kategorion",
     "Mail" : "Retpoŝtilo",
