@@ -39,6 +39,7 @@ OC.L10N.register(
     "Filename" : "Faili nimi",
     "Cancel" : "Loobu",
     "Automatic" : "Automaatne",
+    "Actions" : "Tegevused",
     "Show week numbers" : "Näita nädalanumberid",
     "Settings & import" : "Sätted & importimine",
     "Email" : "Epost",
@@ -57,7 +58,6 @@ OC.L10N.register(
     "Details" : "Üksikasjad",
     "Attendees" : "Osalejad",
     "Reminders" : "Meelespead",
-    "Activity" : "Tegevus",
     "Close" : "Sulge",
     "Anniversary" : "Aastapäev",
     "Appointment" : "Kohtumine",
@@ -68,6 +68,8 @@ OC.L10N.register(
     "Weekly" : "Iga nädal",
     "Monthly" : "Igakuine",
     "Yearly" : "Igaastane",
+    "next year" : "järgmine aasta",
+    "today" : "täna",
     "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
     "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
     "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
@@ -76,7 +78,6 @@ OC.L10N.register(
     "Status" : "Staatus",
     "Confirmed" : "Kinnitatud",
     "Tentative" : "Esialgne",
-    "Cancelled" : "Tühistatud",
     "Categories" : "Kategooriad",
     "Presentation" : "Esitlus",
     "Camping" : "Telkimine",
