@@ -10,6 +10,7 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Halusimme ilmoittaa, että %s on julkaissut kalenterin »%s«.",
     "Open »%s«" : "Avaa »%s«",
     "Cheers!" : "Kiitos!",
+    "Upcoming events" : "Tulevat tapahtumat",
     "Calendar" : "Kalenteri",
     "A Calendar app for Nextcloud" : "Kalenterisovellus Nextcloudille",
     "Previous day" : "Edellinen päivä",
@@ -23,6 +24,7 @@ OC.L10N.register(
     "Day" : "Päivä",
     "Week" : "Viikko",
     "Month" : "Kuukausi",
+    "List" : "Lista",
     "Untitled calendar" : "Nimetön kalenteri",
     "Edit name" : "Muokkaa nimeä",
     "Saving name …" : "Tallennetaan nimi …",
@@ -76,6 +78,7 @@ OC.L10N.register(
     "Creating subscription …" : "Luodaan tilaus …",
     "An error occurred, unable to create the calendar." : "Tapahtui virhe, kalenteria ei voitu luoda.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Anna kelvollinen linkki (alkaen http://, https://, webcal:// tai webcals://)",
+    "Could not update calendar order." : "Kalenterin järjestystä ei voitu päivittää.",
     "Import calendars" : "Tuo kalenterit",
     "Please select a calendar to import into …" : "Valitse kalenteri, johon tuodaan …",
     "Filename" : "Tiedostonimi",
@@ -93,6 +96,8 @@ OC.L10N.register(
     "Shortcut overview" : "Pikakuvakenäkymä",
     "or" : "tai",
     "Navigation" : "Navigointi",
+    "Previous period" : "Edellinen jakso",
+    "Next period" : "Seuraava jakso",
     "Views" : "Näyttökertaa",
     "Day view" : "Päivänäkymä",
     "Week view" : "Viikkonäkymä",
@@ -130,7 +135,6 @@ OC.L10N.register(
     "_week_::_weeks_" : ["viikko","viikkoa"],
     "No reminders yet" : "Ei vielä muistutuksia",
     "Availability of attendees, resources and rooms" : "Osallistujien, resurssien ja huoneiden saatavuus",
-    "Attendees, Resources and Rooms" : "Osallistujat, resurssit ja huoneet",
     "Busy (tentative)" : "Varattu (alustava)",
     "Busy" : "Varattu",
     "Out of office" : "Ulkona toimistolta",
@@ -203,15 +207,20 @@ OC.L10N.register(
     "Please enter a valid date and time" : "Kirjoita kelvollinen päivä ja aika",
     "Type to search timezone" : "Kirjoita etsiäksesi aikavyöhykettä",
     "Personal" : "Henkilökohtainen",
+    "No more events today" : "Ei enempää tapahtumia tänään",
+    "No upcoming events" : "Ei tulevia tapahtumia",
+    "Create a new event" : "Luo uusi tapahtuma",
+    "[Today]" : "[Tänään]",
+    "[Tomorrow]" : "[Huomenna]",
+    "[Yesterday]" : "[Eilen]",
+    "Event does not exist" : "Tapahtumaa ei ole olemassa",
     "Delete this occurrence" : "Poista tämä esiintymä",
     "Delete this and all future" : "Poista tämä ja kaikki tulevat",
     "Details" : "Tiedot",
     "Attendees" : "Osallistujat",
     "Reminders" : "Muistutukset",
-    "Activity" : "Tapahtumat",
-    "Projects" : "Projektit",
-    "Show more details" : "Näytä lisää tietoja",
     "Close" : "Sulje",
+    "Show more details" : "Näytä lisää tietoja",
     "Subscribe to {name}" : "Tilaa {name}",
     "Download {name}" : "Lataa {name}",
     "Anniversary" : "Vuosipäivä",
@@ -248,9 +257,17 @@ OC.L10N.register(
     "Yearly" : "Vuosittain",
     "in {monthNames}" : "kuukausina {monthNames}",
     "_%n time_::_%n times_" : ["%n kerran","%n kertaa"],
-    "_+%n more_::_+%n more_" : ["+%n lisää","+%n lisää"],
     "Untitled event" : "Nimetön tapahtuma",
     "Untitled task" : "Nimetön tehtävä",
+    "next year" : "ensi vuonna",
+    "today" : "tänään",
+    "all-day" : "koko päivä",
+    "%n more" : "%n lisää",
+    "No events to display" : "Ei tapahtumia näytettäväksi",
+    "_+%n more_::_+%n more_" : ["+%n lisää","+%n lisää"],
+    "No events" : "Ei tapahtumia",
+    "It might have been deleted, or there was a typo in a link" : "Se saattaa olla poistettu, tai linkissä oli kirjoitusvirhe",
+    "It might have been deleted, or there was a typo in the link" : "Se saattaa olla poistettu, tai linkissä oli kirjoitusvirhe",
     "When shared show" : "Jaettaessa näytä",
     "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
     "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
@@ -263,7 +280,7 @@ OC.L10N.register(
     "Status" : "Tila",
     "Confirmed" : "Vahvistettu",
     "Tentative" : "Alustava",
-    "Cancelled" : "Peruttu",
+    "Canceled" : "Peruttu",
     "Show as" : "Näytä muodossa",
     "Take this event into account when calculating free-busy information." : "Huomioi tämä tapahtuma laskettaessa vapaita ja varattuja ajankohtia.",
     "Free" : "Vapaa",
