@@ -18,6 +18,7 @@ OC.L10N.register(
     "Day" : "יום",
     "Week" : "שבוע",
     "Month" : "חודש",
+    "List" : "רשימה",
     "Edit name" : "ערוך שם",
     "Saving name …" : "שמירת השם ...",
     "Edit color" : "ערוך צבע",
@@ -116,15 +117,16 @@ OC.L10N.register(
     "Please enter a valid date and time" : "נא להקליד שעה ותאריך תקניים",
     "Type to search timezone" : "יש להקליד כדי לחפש אזור זמן",
     "Personal" : "אישי",
+    "[Today]" : "[היום]",
+    "[Tomorrow]" : "[מחר]",
+    "[Yesterday]" : "[אתמול]",
     "Delete this occurrence" : "מחיקת המופע הזה",
     "Delete this and all future" : "מחיקת זה והבאים",
     "Details" : "פרטים",
     "Attendees" : "משתתפים",
     "Reminders" : "תזכורות",
-    "Activity" : "פעילות",
-    "Projects" : "מיזמים",
-    "Show more details" : "הצגת פרטים נוספים",
     "Close" : "סגירה",
+    "Show more details" : "הצגת פרטים נוספים",
     "Subscribe to {name}" : "הרשמה אל {name}",
     "Download {name}" : "הורדת {name}",
     "Anniversary" : "יום השנה",
@@ -165,9 +167,11 @@ OC.L10N.register(
     "_Every %n year_::_Every %n years_" : ["כל שנה","כל שנתיים","כל %n שנים","כל %n שנים"],
     "until {untilDate}" : "עד {untilDate}",
     "_%n time_::_%n times_" : ["פעם אחת","פעמיים","%n פעמים","%n פעמים"],
-    "_+%n more_::_+%n more_" : ["+ עוד פעם","+ עוד פעמיים","+ עוד %n פעמים","+ עוד %n פעמים"],
     "Untitled event" : "אירוע ללא כותרת",
     "Untitled task" : "משימה ללא כותרת",
+    "next year" : "בשנה הבאה",
+    "today" : "היום",
+    "_+%n more_::_+%n more_" : ["+ עוד פעם","+ עוד פעמיים","+ עוד %n פעמים","+ עוד %n פעמים"],
     "When shared show full event" : "כאשר משותף מציג אירוע מלא",
     "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
     "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
@@ -178,7 +182,7 @@ OC.L10N.register(
     "Status" : "מצב",
     "Confirmed" : "מאושר",
     "Tentative" : "טנטטיבית",
-    "Cancelled" : "בוטל",
+    "Canceled" : "מבוטלת",
     "Show as" : "הצג כ-",
     "Free" : "פנוי",
     "Categories" : "קטגוריות",
