@@ -10,6 +10,7 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "%sがカレンダー»%s«に登録されましたのでお知らせします。",
     "Open »%s«" : "»%s«を開く",
     "Cheers!" : "それでは！",
+    "Upcoming events" : "今後のイベント",
     "Calendar" : "カレンダー",
     "A Calendar app for Nextcloud" : "NextCloudのカレンダーアプリ",
     "Previous day" : "前日",
@@ -23,6 +24,7 @@ OC.L10N.register(
     "Day" : "日",
     "Week" : "週",
     "Month" : "月",
+    "List" : "リスト",
     "Untitled calendar" : "無題のカレンダー",
     "Edit name" : "名前を編集",
     "Saving name …" : "名前を保存しています …",
@@ -76,6 +78,7 @@ OC.L10N.register(
     "Creating subscription …" : "購読を作成中 …",
     "An error occurred, unable to create the calendar." : "エラーが発生したため、カレンダーを作成できません。",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "有効なリンクを入力してください（http:// や https:// 、webcal:// または webcals:// のいずれかで始まる必要があります）",
+    "Could not update calendar order." : "カレンダーの順番を更新できません。",
     "Import calendars" : "カレンダーのインポート",
     "Please select a calendar to import into …" : "インポートするカレンダーを選択してください …",
     "Filename" : "ファイル名",
@@ -131,7 +134,9 @@ OC.L10N.register(
     "_day_::_days_" : ["日"],
     "_week_::_weeks_" : ["週"],
     "No reminders yet" : "まだリマインダーはありません",
+    "Busy (tentative)" : "ビジー (暫定)",
     "Busy" : "ビジー",
+    "Out of office" : "オフィス外",
     "Unknown" : "不明",
     "{name} accepted your invitation." : "{name}が招待を受け入れました。",
     "{name} accepted {organizerName}'s invitation." : "{name}が{organizerName}の招待を受け入れました。",
@@ -154,6 +159,7 @@ OC.L10N.register(
     "No attendees yet" : "出席者はまだいません",
     "(organizer)" : "（主催者）",
     "To send out invitations and handle responses,  [linkopen]add your email address in personal settings[linkclose]." : "招待を送信して返信を受け取るには、[linkopen]個人設定にメールアドレスを追加[linkclose]してください。",
+    "Remove color" : "色を削除",
     "Event title" : "イベントタイトル",
     "All day" : "終日",
     "Can not modify all-day setting for events that are part of a recurrence-set." : "繰り返しの一部であるイベントの終日設定を変更することはできません。",
@@ -172,7 +178,10 @@ OC.L10N.register(
     "fourth" : "4日目",
     "fifth" : "5日目",
     "second to last" : "2日目から最終日",
+    "last" : "最後",
     "Repeat" : "繰り返し",
+    "_month_::_months_" : ["月"],
+    "_year_::_years_" : ["年"],
     "Monday" : "月曜日",
     "weekday" : "平日",
     "weekend day" : "週末",
@@ -180,6 +189,8 @@ OC.L10N.register(
     "More" : "もっと見る",
     "Save" : "保存",
     "Update" : "アップデート",
+    "Update this and all future" : "これ以降を更新",
+    "Public calendar does not exist" : "公開カレンダーは存在しません",
     "Please select a timezone:" : "タイムゾーンを選択してください：",
     "Pick a time" : "時間を指定",
     "Pick a date" : "日付を指定",
@@ -188,14 +199,24 @@ OC.L10N.register(
     "from {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}から",
     "to {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}まで",
     "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
+    "Please enter a valid date" : "有効な日付を入力してください",
+    "Please enter a valid date and time" : "有効な日付と時刻を入力してください",
     "Type to search timezone" : "入力してタイムゾーンを検索",
     "Personal" : "個人",
+    "No more events today" : "今日はこれ以上イベントがありません",
+    "No upcoming events" : "今後のイベントはありません",
+    "Create a new event" : "新しいイベントを作成",
+    "[Today]" : "[今日]",
+    "[Tomorrow]" : "[明日]",
+    "[Yesterday]" : "[昨日]",
+    "Event does not exist" : "イベントは存在しません",
+    "Delete this occurrence" : "この出来事を削除",
     "Details" : "詳細",
     "Attendees" : "参加者",
     "Reminders" : "リマインダー",
-    "Activity" : "アクティビティ",
-    "Projects" : "プロジェクト",
     "Close" : "閉じる",
+    "Show more details" : "詳細を見る",
+    "Download {name}" : "{name}をダウンロード",
     "Anniversary" : "記念日",
     "Appointment" : "アポイントメント",
     "Business" : "ビジネス",
@@ -217,14 +238,27 @@ OC.L10N.register(
     "{time} after the event starts" : "イベント開始 {time} 後",
     "{time} after the event ends" : "イベント終了 {time} 後",
     "Week {number} of {year}" : "{year}の{number} 週",
+    "Does not repeat" : "繰り返さない",
     "Daily" : "毎日",
     "Weekly" : "毎週",
+    "Monthly" : "毎月",
+    "Yearly" : "毎年",
     "_Every %n day_::_Every %n days_" : ["%n日ごと"],
     "_Every %n week_::_Every %n weeks_" : ["%n週ごと"],
     "_Every %n month_::_Every %n months_" : ["%n月ごと"],
     "_Every %n year_::_Every %n years_" : ["%n年ごと"],
     "_%n time_::_%n times_" : ["%n回"],
     "Untitled event" : "無題のイベント",
+    "prev" : "前へ",
+    "next" : "次へ",
+    "prev year" : "前の年へ",
+    "next year" : "来年",
+    "today" : "今日",
+    "list" : "リスト",
+    "W" : "W",
+    "all-day" : "一日中",
+    "No events to display" : "表示するイベントはありません",
+    "No events" : "イベントはありません",
     "When shared show full event" : "共有時にすべてのイベントを表示",
     "When shared show only busy" : "共有時に実行中のみを表示",
     "When shared hide this event" : "共有時にこのイベントを隠す",
@@ -235,10 +269,14 @@ OC.L10N.register(
     "Status" : "ステータス",
     "Confirmed" : "確認済み",
     "Tentative" : "暫定的",
-    "Cancelled" : "キャンセル済",
+    "Canceled" : "キャンセル済み",
+    "Show as" : "として表示",
+    "Free" : "無料",
     "Categories" : "カテゴリ",
     "Search or add categories" : "カテゴリを検索または追加",
     "Add this as a new category" : "これを新しいカテゴリーとして追加",
+    "Custom color" : "カスタム色",
+    "Chat room for event" : "イベントのチャットルーム",
     "Meditation" : "座禅",
     "Relaxing" : "休暇",
     "Relax" : "休み",
@@ -286,6 +324,7 @@ OC.L10N.register(
     "Exercise" : "エクササイズ",
     "Work out" : "運動",
     "Working out" : "筋トレ",
+    "Gym" : "ジム",
     "Barber" : "散髪",
     "Haircut" : "美容院",
     "Exam" : "試験",
@@ -296,6 +335,11 @@ OC.L10N.register(
     "Running" : "ランニング",
     "Go for a run" : "ジョギング",
     "Marathon" : "マラソン",
+    "Video-conference" : "ビデオコンファレンス",
+    "Conference-call" : "コンファレンスコール",
+    "Video-call" : "ビデオコール",
+    "Video-chat" : "ビデオチャット",
+    "Video-meeting" : "ビデオミーティング",
     "Call" : "電話",
     "Calling" : "連絡",
     "Christmas" : "クリスマス",
@@ -304,6 +348,7 @@ OC.L10N.register(
     "Travelling" : "旅行",
     "Journey" : "旅",
     "Collaborate" : "一緒",
+    "Pair" : "ペア",
     "Lecture" : "講義",
     "Seminar" : "ゼミ",
     "Photograph" : "写真",
@@ -314,6 +359,7 @@ OC.L10N.register(
     "Wine tasting" : "ワイン",
     "Golf" : "ゴルフ",
     "Dinner" : "ディナー",
+    "Lunch" : "ランチ",
     "Global" : "グローバル"
 },
 "nplurals=1; plural=0;");
