@@ -11,6 +11,7 @@ OC.L10N.register(
     "Day" : "დღე",
     "Week" : "კვირა",
     "Month" : "თვე",
+    "List" : "ჩამონათვალი",
     "Download" : "ჩამოტვირთვა",
     "Delete" : "წაშლა",
     "Share link" : "ბმულის გაზიარება",
@@ -40,12 +41,13 @@ OC.L10N.register(
     "Details" : "დეტლაები",
     "Attendees" : "დამსწრეები",
     "Reminders" : "შემახსენებლები",
-    "Activity" : "აქტივობა",
     "Close" : "დახურვა",
     "Anniversary" : "დაბადების დღე",
     "Week {number} of {year}" : "კვირა {number} {year}-დან",
     "Daily" : "ყოველდღიური",
     "Weekly" : "ყოველკვირეული",
+    "next year" : "შემდეგი წელი",
+    "today" : "დღეს",
     "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
     "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
     "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა",
@@ -54,7 +56,6 @@ OC.L10N.register(
     "Status" : "სტატუსი",
     "Confirmed" : "დადასტურებლია",
     "Tentative" : "საცდელი",
-    "Cancelled" : "უარყოფილია",
     "Categories" : "კატეგორიები",
     "Mail" : "ფოსტა",
     "Play" : "დაკვრა",
