@@ -23,6 +23,7 @@ OC.L10N.register(
     "Day" : "일",
     "Week" : "주",
     "Month" : "달",
+    "List" : "목록",
     "Untitled calendar" : "제목없는 일정",
     "Edit name" : "이름 편집",
     "Saving name …" : "이름 저장 중...",
@@ -54,6 +55,7 @@ OC.L10N.register(
     "Automatic" : "자동",
     "Actions" : "동작",
     "Show week numbers" : "주 번호 보이기",
+    "Show keyboard shortcuts" : "키보드 단축키 표시",
     "Settings & import" : "설정 및 가져오기",
     "Notification" : "알림",
     "Email" : "이메일",
@@ -73,13 +75,13 @@ OC.L10N.register(
     "Details" : "자세한 정보",
     "Attendees" : "참석자",
     "Reminders" : "알림",
-    "Activity" : "활동",
-    "Projects" : "프로젝트",
     "Close" : "닫기",
     "Anniversary" : "기념일",
     "Week {number} of {year}" : "{year}년 제 {number}주",
     "Daily" : "매일",
     "Weekly" : "매주",
+    "next year" : "내년",
+    "today" : "오늘",
     "When shared show full event" : "전체 일정 공유",
     "When shared show only busy" : "바쁨/한가함만 공유",
     "When shared hide this event" : "일정 공유하지 않음",
@@ -88,7 +90,7 @@ OC.L10N.register(
     "Status" : "상태",
     "Confirmed" : "확인됨",
     "Tentative" : "예정됨",
-    "Cancelled" : "취소됨",
+    "Canceled" : "취소됨",
     "Categories" : "분류",
     "Presentation" : "프레젠테이션",
     "Movie" : "영화",
