@@ -12,6 +12,7 @@ OC.L10N.register(
     "Day" : "Diena",
     "Week" : "Nedēļa",
     "Month" : "Mēnesis",
+    "List" : "Saraksts",
     "Download" : "Lejupielādēt",
     "Delete" : "Dzēst",
     "Share link" : "Koplietot saiti",
@@ -22,6 +23,7 @@ OC.L10N.register(
     "Filename" : "Datnes nosaukums",
     "Cancel" : "Atcelt",
     "Automatic" : "Automātisks",
+    "Actions" : "Darbības",
     "Show week numbers" : "Rādīt nedēļu numurus",
     "Settings & import" : "Iestatījumi un imports",
     "Notification" : "Paziņojums",
@@ -37,18 +39,16 @@ OC.L10N.register(
     "More" : "Vairāk",
     "Save" : "Saglabāt",
     "Update" : "Atjaunināt",
-    "Select Date" : "Izvēlieties datumu",
     "Personal" : "Personīgs",
     "Details" : "Detaļas",
     "Attendees" : "Apmeklētāji",
     "Reminders" : "Atgādinājumi",
-    "Activity" : "Darbības",
-    "Projects" : "Projekti",
     "Close" : "Aizvērt",
     "Anniversary" : "Gadadiena",
     "Week {number} of {year}" : "{number} nedēļa no {year}",
     "Daily" : "Katru dienu",
     "Weekly" : "Katru nedēļu",
+    "today" : "šodien",
     "When shared show full event" : "Ja koplietots, tad rādīt pilnu notikumu",
     "When shared show only busy" : "Ja koplietots, tad rādīt tikai aizņemts",
     "When shared hide this event" : "Ja koplietots, tad paslēpt notikumu",
@@ -57,7 +57,6 @@ OC.L10N.register(
     "Status" : "Status",
     "Confirmed" : "Apstiprināts",
     "Tentative" : "Mēģinājums",
-    "Cancelled" : "Atcelts",
     "Categories" : "Kategorijas",
     "Presentation" : "Prezentācija",
     "Mail" : "E-pasts",
