@@ -37,7 +37,7 @@ OC.L10N.register(
     "Calendar link could not be copied to clipboard." : "Линк до календарот неможе да се копира во клипборд.",
     "An error occurred, unable to rename the calendar." : "Настана грешка, неможе да се преименува календарот.",
     "An error occurred, unable to change the calendar's color." : "Настана грешка, неможе да се променат боите на календарот.",
-    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Одстранување на споделувањето на календарот за 1 секунда","Одстранување на споделувањето на календарот за {countdown} секунди"],
+    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Отстранување на споделување на календар за 1 секунда","Отстранување на споделување на календар за {countdown} секунди"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Бришење на календарот за 1 секунда","Бришење на календарот за {countdown} секунди"],
     "Share link" : "Сподели линк",
     "Publish calendar" : "Објави календар",
@@ -80,12 +80,18 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events._" : ["Успешно увезен %n настан","Успешно увезени %n настани."],
     "Automatic" : "Автоматски",
     "Automatic ({detected})" : "Автоматски ({detected})",
+    "or" : "или",
+    "Navigation" : "Навигација",
     "Actions" : "Акции",
+    "Show shortcuts" : "Прикажи кратенки",
     "Enable birthday calendar" : "Овозможи календар со родендени",
     "Enable simplified editor" : "Овозможи поедноставен уредувач",
     "Show weekends" : "Прикажи викенди",
     "Show week numbers" : "Прикажи броеви на неделите",
+    "Show keyboard shortcuts" : "Прикажи кратенки преку тастатура",
     "Settings & import" : "Параметри & импорт",
+    "CalDAV link copied to clipboard." : "CalDAV линкот е копиран.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV линкот неможе да биде копиран.",
     "before at" : "пред",
     "Notification" : "Известување",
     "Email" : "Е-пошта",
@@ -94,7 +100,7 @@ OC.L10N.register(
     "On date" : "На датум",
     "Edit time" : "Удери време",
     "Save time" : "Зачувај време",
-    "Remove reminder" : "Одстрани потсетник",
+    "Remove reminder" : "Отстрани потсетник",
     "on" : "на",
     "at" : "во",
     "+ Add reminder" : "+ Додади потсетник",
@@ -124,7 +130,7 @@ OC.L10N.register(
     "No attendees yet" : "Сè уште нема присутни",
     "(organizer)" : "(organizer)",
     "To send out invitations and handle responses,  [linkopen]add your email address in personal settings[linkclose]." : "За да испратите покана и да можете да добивате одговори,  [linkopen]додадете ја вашата е-пошта адреса во личните податоци на сметката[linkclose].",
-    "Remove color" : "Одстрани боја",
+    "Remove color" : "Отстрани боја",
     "Event title" : "Наслов на настанот",
     "All day" : "Сите денови",
     "from {startDate}" : "од {startDate}",
@@ -171,15 +177,17 @@ OC.L10N.register(
     "Please enter a valid date and time" : "Внесете валиден датум и време",
     "Type to search timezone" : "Пребарај временски зони",
     "Personal" : "Лично",
+    "[Today]" : "[Денес]",
+    "[Tomorrow]" : "[Утре]",
+    "[Yesterday]" : "[Вчера]",
+    "[Last] dddd" : "[Последна] dddd",
     "Delete this occurrence" : "Избришете ја оваа можност",
     "Delete this and all future" : "Избришете го овој и сете во иднина",
     "Details" : "Детали",
     "Attendees" : "Присутни",
     "Reminders" : "Потсетници",
-    "Activity" : "Активност",
-    "Projects" : "Проекти",
-    "Show more details" : "Прикажи повече детали",
     "Close" : "Затвори",
+    "Show more details" : "Прикажи повече детали",
     "Subscribe to {name}" : "Претплатете се на {name}",
     "Download {name}" : "Преземи {name}",
     "Anniversary" : "Годишнина",
@@ -219,8 +227,18 @@ OC.L10N.register(
     "in {monthNames}" : "во {monthNames}",
     "until {untilDate}" : "до {untilDate}",
     "_%n time_::_%n times_" : ["уште еднаш","%n пати"],
-    "_+%n more_::_+%n more_" : ["+%n друг","+%n други"],
     "Untitled event" : "Неименуван настан",
+    "Untitled task" : "Неименувана задача",
+    "prev" : "предходна",
+    "next" : "следна",
+    "prev year" : "предходна година",
+    "next year" : "следниот месец",
+    "today" : "денес",
+    "list" : "лист",
+    "W" : "Н",
+    "all-day" : "Сите денови",
+    "%n more" : "%n други",
+    "_+%n more_::_+%n more_" : ["+%n друг","+%n други"],
     "When shared show full event" : "Кога е споделен, прикажи го целосно настанот",
     "When shared show only busy" : "Кога е споделено покажи зафатен",
     "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар.",
@@ -231,7 +249,6 @@ OC.L10N.register(
     "Status" : "Статус",
     "Confirmed" : "Потврдено",
     "Tentative" : "Прелиминарен",
-    "Cancelled" : "Откажано",
     "Confirmation about the overall status of the event." : "Потврда за целокупниот статус на настанот.",
     "Show as" : "Крикажи како",
     "Take this event into account when calculating free-busy information." : "Го има во предвид овој настан при пресметување на информации за слободен-зафатен.",
