@@ -21,6 +21,7 @@ OC.L10N.register(
     "Day" : "Dag",
     "Week" : "Uke",
     "Month" : "Måned",
+    "List" : "Liste",
     "Untitled calendar" : "Kalender uten tittel",
     "Edit name" : "Rediger navn",
     "Saving name …" : "Lagrer navn ...",
@@ -133,7 +134,6 @@ OC.L10N.register(
     "_week_::_weeks_" : ["uke","uker"],
     "No reminders yet" : "Ingen påminnelser enda",
     "Availability of attendees, resources and rooms" : "Tilgjengelighet til deltagere, ressurser og rom",
-    "Attendees, Resources and Rooms" : "Deltagere, ressurser og rom",
     "Busy (tentative)" : "Opptatt (foreløpig)",
     "Busy" : "Opptatt",
     "Out of office" : "Fraværende",
@@ -158,6 +158,7 @@ OC.L10N.register(
     "Remove attendee" : "Fjern deltaker",
     "Search for e-mails, users, contacts, resources or rooms" : "Søk for e-poster, brukere, kontakter, ressurser eller rom",
     "No match found" : "Ingen treff",
+    "No attendees yet" : "Ingen deltagere enda",
     "(organizer)" : "(organisator)",
     "Remove color" : "Fjern farge",
     "Event title" : "Tittel på hendelsen",
@@ -210,10 +211,8 @@ OC.L10N.register(
     "Details" : "Detaljer",
     "Attendees" : "Deltakere",
     "Reminders" : "Varsler",
-    "Activity" : "Aktivitet",
-    "Projects" : "Prosjekter",
-    "Show more details" : "Vis flere detaljer",
     "Close" : "Lukk",
+    "Show more details" : "Vis flere detaljer",
     "Subscribe to {name}" : "Abonner på {name}",
     "Download {name}" : "Last ned {name}",
     "Anniversary" : "Jubileum",
@@ -236,9 +235,15 @@ OC.L10N.register(
     "Weekly" : "Ukentlig",
     "Monthly" : "Månedlig",
     "Yearly" : "Årlig",
+    "Untitled event" : "Hendelse uten tittel",
+    "Untitled task" : "Oppgave uten tittel",
+    "next year" : "neste år",
+    "today" : "i dag",
+    "When shared show" : "Når delt vis",
     "When shared show full event" : "Vis hele hendelsen når delt",
     "When shared show only busy" : "Vis kun opptatt når delt",
     "When shared hide this event" : "Skjul denne hendelsen når delt",
+    "The visibility of this event in shared calendars." : "Synlighet for denne oppføringen i delte kalendere",
     "Location" : "Sted",
     "Add a location" : "Legg til et sted",
     "Description" : "Beskrivelse",
@@ -246,7 +251,7 @@ OC.L10N.register(
     "Status" : "Status",
     "Confirmed" : "Bekreftet",
     "Tentative" : "Foreløpig",
-    "Cancelled" : "Avbrutt",
+    "Canceled" : "Avbrutt",
     "Show as" : "Vis som",
     "Free" : "Ledig",
     "Categories" : "Kategorier",
@@ -254,11 +259,79 @@ OC.L10N.register(
     "Add this as a new category" : "Legg til som ny kategori",
     "Custom color" : "Tilpasset farge",
     "Imported {filename}" : "Importerte {filename}",
+    "Meditation" : "Meditasjon",
+    "Relaxing" : "Avslapping",
     "Presentation" : "Presentasjon",
+    "Present" : "Gave",
+    "Camping" : "Camping",
+    "Movie" : "Film",
+    "Cinema" : "Kino",
+    "Brainstorm" : "Brainstorm",
+    "Meet" : "Møte",
+    "Planning" : "Planlegge",
     "Review" : "Anmeldelse",
     "Office" : "Office",
+    "Party" : "Fest",
+    "Celebration" : "Feiring",
     "Mail" : "E-post",
+    "Soccer" : "Fotball",
+    "Gaming" : "Gaming",
     "Play" : "Spill",
+    "Drive" : "Kjøre",
+    "Bicycle" : "Sykkel",
+    "Cycle" : "Sykle",
+    "Biking" : "Sykling",
+    "Podcast" : "Podkast",
+    "Fishing" : "Fisking",
+    "Hiking" : "Tur",
+    "Art" : "Kunst",
+    "Exhibition" : "Utstilling",
+    "Museum" : "Museum",
+    "Pilates" : "Pilates",
+    "Park" : "Park",
+    "Studying" : "Studere",
+    "Doctor" : "Doktor",
+    "Health" : "Helse",
+    "Dentist" : "Tannlege",
+    "Interview" : "Intervju",
+    "Training" : "Trene",
+    "Practice" : "Øve",
+    "Sports" : "Sport",
+    "Gym" : "Gym",
+    "Barber" : "Barberer",
+    "Haircut" : "Frisør",
+    "Exam" : "Eksamen",
+    "Working" : "Jobb",
+    "New Years Eve" : "Nyttårsaften",
+    "Fireworks" : "Fyrverkeri",
+    "Running" : "Løpe",
+    "Go for a run" : "Løpetur",
+    "Marathon" : "Maraton",
+    "Video-conference" : "Videokonferanse",
+    "Conference-call" : "Telefonkonferanse",
+    "Video-call" : "Videosamtale",
+    "Video-chat" : "Videosamtale",
+    "Video-meeting" : "Videokonferanse",
+    "Call" : "Ringe",
+    "Calling" : "Ringer",
+    "Christmas" : "Jul",
+    "Conference" : "Konferanse",
+    "Pizza" : "Pizza",
+    "Travelling" : "Reise",
+    "Journey" : "Reise",
+    "Collaborate" : "Samarbeide",
+    "Pair" : "Par",
+    "Lecture" : "Forelesning",
+    "Seminar" : "Seminar",
+    "Photograph" : "Fotografere",
+    "Celebrate" : "Feire",
+    "Shopping" : "Shoppe",
+    "Skate" : "Skate",
+    "Skateboard" : "Skatebrett",
+    "Wine tasting" : "Vinsmaking",
+    "Golf" : "Golf",
+    "Dinner" : "Middag",
+    "Lunch" : "Lunsj",
     "Global" : "Global"
 },
 "nplurals=2; plural=(n != 1);");
