@@ -61,12 +61,13 @@ OC.L10N.register(
     "Details" : "Detalii",
     "Attendees" : "Participanți",
     "Reminders" : "Mementouri",
-    "Activity" : "Activitate",
     "Close" : "Închide",
     "Anniversary" : "Aniversare",
     "Week {number} of {year}" : "Săptămâna {number} din {year}",
     "Daily" : "Zilnic",
     "Weekly" : "Săptămânal",
+    "next year" : "anul viitor",
+    "today" : "astăzi",
     "When shared show full event" : "Arată tot evenimentul la partajare",
     "When shared show only busy" : "Arată doar ocupat la partajare",
     "When shared hide this event" : "Ascunde evenimentul la partajare",
@@ -75,7 +76,6 @@ OC.L10N.register(
     "Status" : "Stare",
     "Confirmed" : "Confirmat",
     "Tentative" : "Tentativă",
-    "Cancelled" : "Anulat",
     "Mail" : "Mail",
     "Play" : "Redă",
     "Global" : "Global"
