@@ -13,7 +13,6 @@ OC.L10N.register(
     "Cancel" : "එපා",
     "Email" : "විද්‍යුත් තැපෑල",
     "Unknown" : "නොදනී",
-    "from" : "වෙතින්",
     "never" : "කවදාවත්",
     "Repeat" : "පුනරාවර්ථන",
     "Monday" : "සඳුදා",
@@ -22,10 +21,10 @@ OC.L10N.register(
     "Update" : "යාවත්කාල කිරීම",
     "Personal" : "පෞද්ගලික",
     "Attendees" : "කැටුව යන්නන්",
-    "Activity" : "ක්‍රියාකාරකම",
     "Close" : "වසන්න",
     "Daily" : "දිනපතා",
     "Weekly" : "සතිපතා",
+    "today" : "අද",
     "Location" : "ස්ථානය",
     "Description" : "විස්තරය",
     "Mail" : "තැපෑල",
