@@ -12,6 +12,7 @@ OC.L10N.register(
     "Day" : "Дан",
     "Week" : "Недеља",
     "Month" : "Месец",
+    "List" : "Излистај",
     "Copy private link" : "Копирај приватну везу",
     "Download" : "Преузми",
     "Delete" : "Обриши",
@@ -28,6 +29,8 @@ OC.L10N.register(
     "Filename" : "Име фајла",
     "Cancel" : "Одустани",
     "Automatic" : "Аутоматски",
+    "or" : "или",
+    "Actions" : "Радње",
     "Show week numbers" : "Прикажи број седмице",
     "Settings & import" : "Поставке & увоз",
     "Notification" : "Обавештење",
@@ -43,19 +46,22 @@ OC.L10N.register(
     "More" : "Остало",
     "Save" : "Сачувај",
     "Update" : "Ажурирај",
-    "Select Date" : "Одаберите датум",
     "Personal" : "Лично",
+    "[Today]" : "[Данас]",
+    "[Tomorrow]" : "[Сутра]",
+    "[Yesterday]" : "[Јуче]",
     "Details" : "Детаљи",
     "Attendees" : "Присутни",
     "Reminders" : "Подсетници",
-    "Activity" : "Активност",
-    "Projects" : "Пројекти",
     "Close" : "Затвори",
     "Anniversary" : "Годишњица",
     "Week {number} of {year}" : "Недеља {number} у {year}",
     "Daily" : "дневно",
     "Weekly" : "недељно",
     "Untitled event" : "Неименовани догађај",
+    "Untitled task" : "Неименовани задатак",
+    "next year" : "следеће године",
+    "today" : "данас",
     "When shared show full event" : "Прикажи цео догађај када је догађај дељен",
     "When shared show only busy" : "Прикажи само да сте заузети када је догађај дељен",
     "When shared hide this event" : "Сакриј догађај када је догађај дељен",
@@ -64,7 +70,7 @@ OC.L10N.register(
     "Status" : "Статус",
     "Confirmed" : "Потврђен",
     "Tentative" : "Условна потврда",
-    "Cancelled" : "Отказано",
+    "Canceled" : "Отказано",
     "Categories" : "Категорије",
     "Add this as a new category" : "Додај ово као нову категорију",
     "Movie" : "Филм",
