@@ -17,12 +17,10 @@ OC.L10N.register(
     "Save" : "Save",
     "Update" : "Ažuriraj",
     "Details" : "Detalji",
-    "Activity" : "Активност",
     "Close" : "Zatvori",
     "Daily" : "дневно",
     "Weekly" : "недељно",
     "Description" : "Opis",
-    "Cancelled" : "Otkazano",
     "Movie" : "Film",
     "Mail" : "Pošta"
 },
