@@ -23,6 +23,7 @@ OC.L10N.register(
     "Day" : "日",
     "Week" : "週",
     "Month" : "月",
+    "List" : "清單",
     "Untitled calendar" : "未命名日曆",
     "Edit name" : "編輯名稱",
     "Saving name …" : "儲存名稱 …",
@@ -55,8 +56,10 @@ OC.L10N.register(
     "Automatic" : "自動",
     "or" : "或者",
     "Actions" : "動作",
+    "Show weekends" : "顯示週末",
     "Show week numbers" : "顯示週數",
     "Settings & import" : "設定及匯入",
+    "CalDAV link copied to clipboard." : "已複製 CalDAV 連結至剪貼簿",
     "Notification" : "通知",
     "Email" : "Email",
     "Edit time" : "編輯時間",
@@ -99,10 +102,8 @@ OC.L10N.register(
     "Details" : "詳細資料",
     "Attendees" : "出席者",
     "Reminders" : "提醒",
-    "Activity" : "活動",
-    "Projects" : "專案項目",
-    "Show more details" : "顯示更多細節",
     "Close" : " 關閉",
+    "Show more details" : "顯示更多細節",
     "Download {name}" : "下載 {name}",
     "Anniversary" : "週年",
     "Appointment" : "約會",
@@ -115,6 +116,8 @@ OC.L10N.register(
     "Week {number} of {year}" : "{year} 的第 {number} 週",
     "Daily" : "每日",
     "Weekly" : "每週",
+    "next year" : "明年",
+    "today" : "今天",
     "When shared show full event" : "分享的時候顯示完整活動",
     "When shared show only busy" : "分享的時候顯示忙碌中",
     "When shared hide this event" : "分享的時候隱藏這個活動",
@@ -123,7 +126,6 @@ OC.L10N.register(
     "Status" : "狀態",
     "Confirmed" : "已確認",
     "Tentative" : "測試的",
-    "Cancelled" : "已取消",
     "Categories" : "分類",
     "Movie" : "電影",
     "Cinema" : "電影院",
